from Microsoft.Win32 import Registry

from System import Environment
from System.Drawing import Icon
from System.IO import Path
from System.Windows.Forms import Application, ContextMenu, MenuItem, MessageBox, \
                                 MessageBoxButtons, NotifyIcon, Timer
from System.Windows import Window
from System.Windows.Threading import DispatcherPriority 

from config import APPLICATION_DIRECTORY, APPLICATION_NAME, OPTIONS_PATH, \
                   QUESTIONS_PATH, RESULTS_PATH, RUNNING_FROM_COMMANDLINE
from drillwindow import DrillWindow
from iconlooper import IconLooper
from options import Options
from optionswindow import OptionsWindow
from pendingquestioncounter import PendingQuestionCounter
from questionmanager import QuestionManager
        
class ControlWindow(Window):
    def _receive_completed(self, message_queue, result):
        try:
            message = message_queue.EndReceive(result.AsyncResult);
            from IronPython.Runtime import CallTarget0
            self.Dispatcher.Invoke(
                DispatcherPriority.Normal, CallTarget0(self.show_drill_window))
            
            message_queue.BeginReceive()
        except Exception, e:
            print e

    def __init__(self, application, message_queue):
        self.drill_window = None

        self.application = application
        self.options = Options(OPTIONS_PATH)
        self.question_manager = QuestionManager(QUESTIONS_PATH, RESULTS_PATH)
        
        message_queue.ReceiveCompleted += self._receive_completed;

        self.options.load()

        self.Title = "Add Questions"

        notification_menu = ContextMenu()
        
        open_menu_item = MenuItem("Open")
        open_menu_item.DefaultItem = True
        open_menu_item.Click += lambda o, e: self.show_drill_window()

        options_menu_item = MenuItem("Options...")
        options_menu_item.Click += lambda o, e: self.show_options_window()
        
        exit_menu_item = MenuItem("Quit")
        exit_menu_item.Click += self._on_quit
        
        notification_menu.MenuItems.Add(open_menu_item)
        notification_menu.MenuItems.Add(options_menu_item)
        notification_menu.MenuItems.Add(MenuItem('-'))        
        notification_menu.MenuItems.Add(exit_menu_item)

        self.pending_question_counter = PendingQuestionCounter(self.options)

        self.notify_icon = NotifyIcon();
        self.notify_icon.Icon = Icon("icon.ico")
        self.notify_icon.Text = "notify_icon"
        self.notify_icon.ContextMenu = notification_menu
        self.notify_icon.DoubleClick += self._on_notify_icon_double_click
        self.notify_icon.Visible = True
        self.icon_looper = IconLooper(
            self.notify_icon, self.pending_question_counter)

        self.application.Exit += self._on_exit    
    
        message_queue.BeginReceive()

    def show_drill_window(self):
        if self.drill_window is None:
            self.drill_window = DrillWindow(
                self.question_manager, self.pending_question_counter)
            self.drill_window.Closed += self._on_drill_closed
            
        self.icon_looper.force_icon = True
        self.drill_window.Show()
        self.drill_window.BringIntoView() # XXX does this do anything?

    def show_options_window(self):
        OptionsWindow(self.options).ShowDialog()
        
    def _on_drill_closed(self, o, v):
        self.icon_looper.force_icon = False
        self.drill_window = None
        
    def _on_quit(self, o, e):
        self.application.Shutdown()
    
    def _on_exit(self, o, e):
        self.notify_icon.Visible = False
        
        self.options.save()
        self._save_autorun_settings()
            
        self.question_manager.save_results()
        
    def _on_notify_icon_double_click(self, o, e):
        self.show_drill_window()

    def _generate_autorun_commandline(self):
        if RUNNING_FROM_COMMANDLINE:
            return '"%s" "%s"' % (
                Application.ExecutablePath,
                Path.Combine(APPLICATION_DIRECTORY, "app.py"))
        else:
            return Application.ExecutablePath
        
    def _save_autorun_settings(self):
        run_key = Registry.CurrentUser.CreateSubKey(
                    r"Software\Microsoft\Windows\CurrentVersion\Run")
        
        if self.options.autorun:
            run_key.SetValue(
                APPLICATION_NAME, self._generate_autorun_commandline())
        else:
            run_key.DeleteSubKey(APPLICATION_NAME, False)
        
        