from questioner import Questioner
from noun import MASCULINE, NEUTER, FEMININE
from xaml import load_xaml

class AvalonNounQuestioner(Questioner):
    def __init__(self):
        self.xaml = load_xaml("nounquestioner.xaml")

        self.prompt_text_block = self._find_name("EnglishPromptTextBlock")
        self.prompt_format_text = self.prompt_text_block.Text

        self.gender_combo_box = self._find_name("GenderComboBox")        
        self.singular_text_box = self._find_name("SingularTextBox")
        self.plural_text_box = self._find_name("PluralTextBox")

        
        self.masculine_combo_box_item = self._find_name("MasculineComboBoxItem")
        self.feminine_combo_box_item = self._find_name("FeminineComboBoxItem")
        self.neuter_combo_box_item = self._find_name("NeuterComboBoxItem")
        
        Questioner.__init__(self)
    
    def _set_selected_gender(self, gender):
        if gender == MASCULINE:
            self.gender_combo_box.SelectedValue = self.masculine_combo_box_item
        elif gender == FEMININE:
            self.gender_combo_box.SelectedValue = self.feminine_combo_box_item
        elif gender == NEUTER:
            self.gender_combo_box.SelectedValue = self.neuter_combo_box_item
        else:
            assert 0
    def _get_selected_gender(self):
        if self.masculine_combo_box_item.IsSelected:
            return MASCULINE
        elif self.feminine_combo_box_item.IsSelected:
            return FEMININE
        elif self.neuter_combo_box_item.IsSelected:
            return NEUTER
        else:
            assert 0
    selected_gender = property(_get_selected_gender, _set_selected_gender)

    def focus(self):
        self.gender_combo_box.Focus()
        
    def set_question(self, noun):
        Questioner.set_question(self, noun)
        
        self.noun = noun
        self.prompt_text_block.Text = self.prompt_format_text % \
                                        self.noun.english

        self.selected_gender = MASCULINE
        self.singular_text_box.Text = ""
        self.plural_text_box.Text = ""
        self.plural_text_box.IsEnabled = self.noun.plural is not None
            
        
    def _is_correct_gender(self):
        return self.selected_gender == self.noun.gender
    
    def _is_correct_singular(self):
        return self.singular_text_box.Text.strip() == self.noun.singular
    
    def _is_correct_plural(self):
        return (self.noun.plural is None) or (
            self.plural_text_box.Text.strip() == self.noun.plural)
        
    def is_correct(self):
        return self._is_correct_gender() and self._is_correct_singular() and \
               self._is_correct_plural()

    def show_answer(self):
        self.selected_gender = self.noun.gender
        self.singular_text_box.Text = self.noun.singular
        if self.noun.plural is not None:
            self.plural_text_box.Text = self.noun.plural
        
    def _find_name(self, name):
        return self.xaml.FindName(name)