from System.Windows import ResizeMode, SizeToContent, Window, WindowStyle, \
                           Visibility
from xaml import load_xaml
from adjective import Adjective
from noun import Noun
from verb import Verb

from avalonadjectivequestioner import AvalonAdjectiveQuestioner
from avalonnounquestioner import AvalonNounQuestioner
from avalonverbquestioner import AvalonVerbQuestioner

class DrillWindow(Window):
    def __init__(self, question_manager, pending_question_counter):
        self.question_manager = question_manager
        self.pending_question_counter = pending_question_counter
        
        self.Title = "Add Questions"
        self.Content = load_xaml("questions.xaml")
        self.SizeToContent = SizeToContent.WidthAndHeight
        self.ResizeMode = ResizeMode.CanMinimize

        self.question_presenter = self._find_name("QuestionPresenter")
        self.next_button = self._find_name("NextButton")
        self.next_button.Click += self._on_next
        self.answer_button = self._find_name("AnswerButton")
        self.answer_button.Click += self.on_answer
        
        self.incorrect_message = self._find_name("IncorrectMessage")
        self.incorrect_message.Visibility = Visibility.Hidden

        self.adjective_questioner = AvalonAdjectiveQuestioner()
        self.noun_questioner = AvalonNounQuestioner()
        self.verb_questioner = AvalonVerbQuestioner()        

        self.do_question()
        
    def do_question(self):
        self.already_answered = False
        self.incorrect_message.Visibility = Visibility.Hidden
                   
        question = self.question_manager.get_question()
        if isinstance(question, Noun):
            self.active_questioner = self.noun_questioner
        elif isinstance(question, Adjective):
            self.active_questioner = self.adjective_questioner
        elif isinstance(question, Verb):
            self.active_questioner = self.verb_questioner
        else:
            raise Exception("unknown question type: %s" % question)
        
        self.active_questioner.set_question(question)
        self.active_questioner.focus()
        self.question_presenter.Content = self.active_questioner.xaml

    def _on_next(self, o, e):        
        if (self.already_answered) or (self.active_questioner.is_correct()):
            if not self.already_answered:
                print '>>>>>>>>>>>>>>>> HERE <<<<<<<<<<<<<<<<<<<'
                self.active_questioner.mark_right()
            
            self.pending_question_counter.num_pending_questions -= 1
            self.do_question()
        else:
            self.active_questioner.mark_wrong()
            self.active_questioner.show_answer()
            self.already_answered = True
            self.incorrect_message.Visibility = Visibility.Visible
    
    def on_answer(self, o, e):
        self.active_questioner.mark_wrong()
        self.active_questioner.show_answer()
        self.already_answered = True
                
    def _find_name(self, name):
        return self.Content.FindName(name)
    