from System.Drawing import Icon
from System.Windows.Forms import Timer

class IconLooper(object):
    def __init__(self, notification_icon, pending_question_counter):
        self.notification_icon = notification_icon
        self._force_icon = False
        
        self.icons = [
            Icon("images/austrianflag.ico"),
            Icon("images/germanflag.ico"),
            Icon("images/liechtensteinflag.ico"),
            Icon("images/luxemburgflag.ico"),
            Icon("images/swissflag.ico"),
            ]
        self.notification_icon.Icon = self.icons[0]
        
        self.timer = Timer()
        self.timer.Tick += self._on_tick
        self.timer.Interval = 5000;

        pending_question_counter.count_changed += self._count_changed
        self._set_num_pending_questions(
            pending_question_counter.num_pending_questions)
        
    def _get_force_icon(self):
        return self._force_icon
    def _set_force_icon(self, v):
        self._force_icon = v
        
        if self.force_icon:
            self.notification_icon.Visible = True
        else:
            self.notification_icon.Visible = self._num_pending_questions > 0
            
    force_icon = property(_get_force_icon, _set_force_icon)
    
    def _set_num_pending_questions(self, num):
        self._num_pending_questions = num
                    
        if self._num_pending_questions == 1:
            self.notification_icon.Text = "%d Frage" % (
                self._num_pending_questions)            
        else:
            self.notification_icon.Text = "%d Fragen" % (
                self._num_pending_questions)

        if self._num_pending_questions == 0:
            self.notification_icon.Visible = self.force_icon
            self.timer.Stop()
        else:
            self.notification_icon.Visible = True
            self.timer.Interval = max(
                (1000 * 60) / self._num_pending_questions, 1000)
            self.timer.Start()

    def _count_changed(self, o, e):
        self._set_num_pending_questions(o.num_pending_questions)
    
    def _on_tick(self, o, e):
        index = self.icons.index(self.notification_icon.Icon)
        if index == len(self.icons) - 1:
            index = 0
        else:
            index = index + 1
            
        self.notification_icon.Icon = self.icons[index]