from question import Question, SkipQuestionException

MASCULINE = 'der'
NEUTER = 'das'
FEMININE = 'die'
GENDERS = (MASCULINE, NEUTER, FEMININE)

class Noun(Question):
    def __init__(self, singular, plural, gender, english, id=None, results=None):
        self.singular = singular
        self.plural = plural
        self.gender = gender
        self.english = english
        
        assert self.gender in GENDERS
        
        Question.__init__(self, id or self.english, results)
    
    def ask_console(self):
        print 'bersetzen Sie: %s' % self.english
        print

        try:
            gender = raw_input("das Geschlecht (der/die/das): ")
            gender = gender.lower().strip()            
            if gender == '':
                raise SkipQuestionException()
                
            singular = raw_input("der Singular: ")
            singular = singular.strip()
            if singular == '':
                raise SkipQuestionException()
        
            if self.plural is None:
                plural = None
            else:
                plural = raw_input("der Plural: ")
                plural = plural.strip()
                if plural == '':
                    raise SkipQuestionException()

        except SkipQuestionException:
            print 'Die richtige Anwort ist: %s %s (%s)' % (
                        self.gender, self.singular, self.plural)
            self.mark_wrong()
        else:            
            if self.gender != gender or singular != self.singular or plural != self.plural:
                print 'Falsch. Die richtige Anwort ist: %s %s (%s)' % (
                            self.gender, self.singular, self.plural)
                self.mark_wrong()
            else:
                print 'Richtig!'
                self.mark_right()
        
    def __repr__(self):
        return '<Noun singular=%s plural=%s gender=%s english=%s>' % (
            self.singular, self.plural, self.gender, self.english)
    
    def to_element(self, document):
        element = document.CreateElement("noun")
        element.SetAttribute("singular", self.singular)
        if self.plural is not None:
            element.SetAttribute("plural", self.plural)

        element.SetAttribute("gender", self.gender)
        element.SetAttribute("english", self.english)
        element.SetAttribute("id", self.id)
        
        return element
    
    def _from_element(cls, element):
        return Noun(
            element.GetAttribute("singular"),
            element.GetAttribute("plural") or None,
            element.GetAttribute("gender"),
            element.GetAttribute("english"),
            element.GetAttribute("id") or None)
    from_element = classmethod(_from_element)
    
    