from System import EventArgs, TimeSpan
from System.IO import File, Path
from System.Xml import XmlDocument

from eventhandlerxxx import EventHandler

STR_TO_TRUTH_TABLE = {
    'yes' : True,
    'no' : False,
    'true' : True,
    'false' : False}

class Options(object):
    def __init__(self, options_file_path):
        self._question_frequency = TimeSpan(hours=0, minutes=60, seconds=0)
        self._autorun = False
        self.options_file_path = options_file_path
        self.changed = EventHandler()
        
    def __repr__(self):
        return "<Options question_frequency=%s autorun=%s>" % (
            self.question_frequency, self.autorun)
    
    def save(self):
        doc = XmlDocument()
        doc_elem = doc.CreateElement("options")
        doc.AppendChild(doc_elem)
        
        freq_elem = doc.CreateElement("question-frequency")
        freq_elem.SetAttribute("value", self.question_frequency.ToString())
        doc_elem.AppendChild(freq_elem)
        
        autorun_elem = doc.CreateElement("autorun")
        autorun_elem.SetAttribute("value", ["no", "yes"][self.autorun])
        doc_elem.AppendChild(autorun_elem)
        
        doc.Save(self.options_file_path)
        
    def load(self):
        if not File.Exists(self.options_file_path):
            return
        
        doc = XmlDocument()
        doc.Load(self.options_file_path)

        frequency = doc.GetElementsByTagName(
            "question-frequency")[0].GetAttribute("value")
        
        self.question_frequency = TimeSpan.Parse(frequency)
        
        autorun = doc.GetElementsByTagName(
            "autorun")[0].GetAttribute("value")
        
        self.autorun = STR_TO_TRUTH_TABLE[autorun.lower()]

    def _get_question_frequency(self):
        return self._question_frequency
    def _set_question_frequency(self, t):
        self._question_frequency = t
        self.changed(self, EventArgs())
    question_frequency = property(
        _get_question_frequency, _set_question_frequency)

    def _get_autorun(self):
        return self._autorun
    def _set_autorun(self, r):
        self._autorun = r
        self.changed(self, EventArgs())
    autorun = property(_get_autorun, _set_autorun)

