if __name__ == '__main__':
    import clr
    clr.AddReferenceByPartialName("System.Windows.Forms")
    clr.AddReferenceByPartialName("System.Drawing")
    clr.AddReferenceByPartialName("PresentationCore")
    clr.AddReferenceByPartialName("PresentationFramework")
    clr.AddReferenceByPartialName("WindowsBase")
    clr.AddReferenceByPartialName("System.Xml")

from System import TimeSpan
from System.Windows import ResizeMode, SizeToContent, Window, Visibility
from xaml import load_xaml

class OptionsWindow(Window):
    def __init__(self, options):
        xaml = load_xaml("options.xaml")
        self.Content = xaml

        self.options = options
        self.SizeToContent = SizeToContent.WidthAndHeight
        self.ResizeMode = ResizeMode.CanMinimize

        self.frequency_description_text_box = self._find_name(
            "FrequencyDescriptionTextBox")
        self.frequency_slider = self._find_name("FrequencySlider")
        self.frequency_slider.Value = \
                self.options.question_frequency.TotalMinutes
        self.frequency_slider.ValueChanged += self._slider_changed

        self.autostart_checkbox = self._find_name("AutoStartCheckBox")
        self.autostart_checkbox.IsChecked = options.autorun
        
        self.cancel_button = self._find_name("CancelButton")
        self.cancel_button.Click += self._on_cancel
        
        self.ok_button = self._find_name("OKButton")
        self.ok_button.Click += self._on_ok
        
        self._set_slider_text(int(self.frequency_slider.Value))
        
    def _on_cancel(self, o, e):
        self.Close()
    
    def _on_ok(self, o, e):
        self.options.question_frequency = TimeSpan(
            hours=0, minutes=int(self.frequency_slider.Value), seconds=0)
        self.options.autorun = self.autostart_checkbox.IsChecked
        
        self.Close()
        
    def _set_slider_text(self, total_minutes):
        hours = total_minutes / 60
        minutes = total_minutes % 60
        
        if hours == 0:
            text = None
        elif hours == 1:
            text = 'jede Stunde'
        else:
            text = "alle %d Stunden" % hours
            
        if minutes == 0:
            pass
        elif minutes == 1:
            if text is not None:
                text += ', eine Minute'
            else:
                text = 'jede Minute'
        else:
            if text is not None:
                text += ', %d Minuten' % minutes
            else:
                text = 'alle %d Minuten' % minutes

        self.frequency_description_text_box.Text = text
        
    def _slider_changed(self, o, e):
        self._set_slider_text(int(e.NewValue))
    
    def _find_name(self, name):
        return self.Content.FindName(name)
    

def main():    
    from System.Windows import Application
    from options import Options
    
    app = Application()
    options = Options()
    options.load()
    app.MainWindow = OptionsWindow(options)
    app.MainWindow.ShowDialog()
    app.Run()
    print options
    options.save()
    
if __name__ == '__main__':
    main()